==> massxpert_2.0.3.orig.tar.gz: massxpert-2.0.3/lib/isotopicPeak.hpp <==
/* massXpert - the true massist's program.
   --------------------------------------
   Copyright(C) 2006,2007 Filippo Rusconi

   http://www.massxpert.org/massXpert

   This file is part of the massXpert project.

   The massxpert project is the successor to the "GNU polyxmass"
   project that is an official GNU project package(see
   www.gnu.org). The massXpert project is not endorsed by the GNU
   project, although it is released ---in its entirety--- under the
   GNU General Public License. A huge part of the code in massXpert
   is actually a C++ rewrite of code in GNU polyxmass. As such
   massXpert was started at the Centre National de la Recherche
   Scientifique(FRANCE), that granted me the formal authorization to
   publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License version 3, as published by the Free Software Foundation.
   

   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this software; if not, write to the

   Free Software Foundation, Inc.,

   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef ISOTOPIC_PEAK_HPP
#define ISOTOPIC_PEAK_HPP


/////////////////////// Qt includes
#include <QtGlobal>
#include <QtXml>


/////////////////////// Local includes
#include "isotope.hpp"


namespace massXpert
{

  //! The IsotopicPeak class provides an isotopic peak.
  /*! Isotopic peaks represent peaks that comprise the isotopic
    multiplet observed when a mass spectrometrer has enough resolution
    to resolve each isotopic peak forming an isotopic pattern. Isotopic
    peaks derive from Isotope and have additional characteristic
    data:
  
    \li the isotope peak probability;
    \li the isotope peak relative intensity.
  */
  class IsotopicPeak : public Isotope
  {
  private:
    // Probability of occurrence.
    double m_probability;

    // Relative intensity of this peak with respect to all the others in
    // the pattern.
    double m_relativeIntensity;
  
  public:
    IsotopicPeak(double = 0, double = 0, double = 0, double = 0);
    IsotopicPeak(Isotope &, double = 0, double = 0);
    IsotopicPeak(const IsotopicPeak &);

    virtual IsotopicPeak * clone() const;
    virtual void clone(IsotopicPeak *) const;
    virtual void mold(const IsotopicPeak &);
    virtual IsotopicPeak & operator =(const IsotopicPeak &);
  
    void setProbability(double);
    void incrementProbability(double);
    double probability() const;
    QString probability(const QLocale &, int = 10) const;
  
    void setRelativeIntensity(double);
    double relativeIntensity() const;
    QString relativeIntensity(const QLocale &, int = 10) const;
  };
  
} // namespace massXpert


#endif // ISOTOPIC_PEAK_HPP

==> massxpert_3.0.0.orig.tar.gz: massxpert-3.0.0/lib/isotopicPeak.hpp <==
/* massXpert - the true massist's program.
   --------------------------------------
   Copyright(C) 2006,2007 Filippo Rusconi

   http://www.massxpert.org/massXpert

   This file is part of the massXpert project.

   The massxpert project is the successor to the "GNU polyxmass"
   project that is an official GNU project package(see
   www.gnu.org). The massXpert project is not endorsed by the GNU
   project, although it is released ---in its entirety--- under the
   GNU General Public License. A huge part of the code in massXpert
   is actually a C++ rewrite of code in GNU polyxmass. As such
   massXpert was started at the Centre National de la Recherche
   Scientifique(FRANCE), that granted me the formal authorization to
   publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License version 3, as published by the Free Software Foundation.
   

   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this software; if not, write to the

   Free Software Foundation, Inc.,

   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef ISOTOPIC_PEAK_HPP
#define ISOTOPIC_PEAK_HPP


/////////////////////// Qt includes
#include <QtGlobal>
#include <QtXml>


/////////////////////// Local includes
#include "isotope.hpp"


namespace massXpert
{

  //! The IsotopicPeak class provides an isotopic peak.
  /*! Isotopic peaks represent peaks that comprise the isotopic
    multiplet observed when a mass spectrometrer has enough resolution
    to resolve each isotopic peak forming an isotopic pattern. Isotopic
    peaks derive from Isotope and have additional characteristic
    data:
  
    \li the isotope peak probability;
    \li the isotope peak relative intensity.
  */
  class IsotopicPeak : public Isotope
  {
  private:
    // Probability of occurrence.
    double m_probability;

    // Relative intensity of this peak with respect to all the others in
    // the pattern.
    double m_relativeIntensity;
  
  public:
    IsotopicPeak(double /* mass */, double /* relIntensity */,
                 double /* probability */, double /* abundance */);
    IsotopicPeak(Isotope &, double, double);
    IsotopicPeak(const IsotopicPeak &);

    virtual IsotopicPeak * clone() const;
    virtual void clone(IsotopicPeak *) const;
    virtual void mold(const IsotopicPeak &);
    virtual IsotopicPeak & operator =(const IsotopicPeak &);
  
    void setProbability(double);
    void incrementProbability(double);
    double probability() const;
    QString probability(const QLocale &, int = 10) const;
  
    void setRelativeIntensity(double);
    double relativeIntensity() const;
    QString relativeIntensity(const QLocale &, int = 10) const;
  };
  
} // namespace massXpert


#endif // ISOTOPIC_PEAK_HPP
